<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Abrir imagem</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Aparência</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Bordas chanfradas</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Sombras externas</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Cores</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Fundo:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Sombra:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Realce:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Faltando imagem.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Por favor aguarde</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Carregando imagem...</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Gerando quebra-cabeças...</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Criando peças...</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Carregando quebra-cabeças...</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Formato de dados desconhecido</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>Elemento desconhecido &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Erro ao interpretar arquivo XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Carregando peças...</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Recuperando peças...</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Posicionando peças...</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Escolha um jogo</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Jogos atuais</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Novo jogo</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Propriedades da imagem</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Tags:</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecione o idioma do jogo:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma do sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor reinicie o jogo para que a alteração do idioma faça efeito.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Adicionar imagem</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Remover imagem</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Propriedades da imagem</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 peças</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Copiando imagens..</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cacelar</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sem título</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Sem título</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 peças %2 %3 completas</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Excluir jogo</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Excluir jogo selecionado?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Visão geral</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Adicionar tag</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Remover tag</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Sem tags</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Todas as imagens</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sem título %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Remover a tag selecionada?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Uma tag com este nome já existe.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jogo</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Recuperar peças</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Sai&amp;r</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Escolher...</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Visualizar</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Aumentar Zoom</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Diminuir Zoom</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Ajustar à &amp;tela</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Exibir &amp;visão geral</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>Tela &amp;cheia</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configurações</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Aparência...</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Idioma...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;juda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controles</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Sobre o &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controles</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Pegar peças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Clique esquerdo ou espaço</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Deixar peças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Selecionar peças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Arrastar com botão esquerdo</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Girar peças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Clique direito, Control + clique esquerdo, ou R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Arrastar quebra-cabeças:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Clique no meio, Shift + Clique esquerdo, ou setas direcionais</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Aumentar/diminuir zoom:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Roda do mouse ou +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mover cursor:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Mova o mouse ou W, A, S, D</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Sobre o Teztle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Quebra-cabeças com peças em formato de tetris</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Licenciado sob os termos da &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
